Block

Struct Block 

pub struct Block { /* private fields */ }
A block is a collection of named columns with the same number of rows

Implementations

Source

impl Block

pub fn new() -> Self

Create a new empty block

pub fn with_capacity(cols: usize, rows: usize) -> Self

Create a block with reserved capacity

pub fn append_column( &mut self, name: impl Into<String>, column: ColumnRef, ) -> Result<()>

Append a named column to the block

pub fn column_count(&self) -> usize

Get the number of columns in the block

pub fn row_count(&self) -> usize

Get the number of rows in the block

pub fn column(&self, index: usize) -> Option<ColumnRef>

Get column by index

pub fn column_mut(&mut self, index: usize) -> Option<&mut (dyn Column + '_)>

Get mutable access to column by index Returns None if index is out of bounds Panics if the column has multiple references

pub fn column_name(&self, index: usize) -> Option<&str>

Get column name by index

pub fn column_by_name(&self, name: &str) -> Option<ColumnRef>

Get column by name

pub fn column_by_name_mut( &mut self, name: &str, ) -> Option<&mut (dyn Column + '_)>

Get mutable access to column by name Returns None if column with given name is not found Panics if the column has multiple references

pub fn info(&self) -> &BlockInfo

Get block info

pub fn set_info(&mut self, info: BlockInfo)

Set block info

pub fn clear(&mut self)

Clear all data from all columns

pub fn reserve(&mut self, new_cap: usize)

Reserve capacity in all columns

pub fn refresh_row_count(&mut self) -> Result<usize>

Refresh and validate row count

pub fn iter(&self) -> BlockIterator<'_>

Iterate over columns

pub fn is_empty(&self) -> bool

Check if block is empty