ColumnArray

Struct ColumnArray 

pub struct ColumnArray { /* private fields */ }
Column for arrays of variable length

Stores a nested column with all array elements concatenated, and an offsets array that marks where each array ends.

Reference Implementation: See clickhouse-cpp/clickhouse/columns/array.cpp

Implementations

Source

impl ColumnArray

pub fn new(type_: Type) -> Self

Create a new array column from an array type

pub fn with_nested(nested: ColumnRef) -> Self

Create a new array column with an existing nested column

pub fn with_capacity(type_: Type, capacity: usize) -> Self

Create with reserved capacity

pub fn append_len(&mut self, len: u64)

Append an array (specified by the number of elements in the nested column to consume) The caller must ensure that len elements have been added to the nested column

pub fn get_array_range(&self, index: usize) -> Option<(usize, usize)>

Get the start and end indices for the array at the given index

pub fn get_array_len(&self, index: usize) -> Option<usize>

Get the length of the array at the given index

pub fn nested<T: Column + 'static>(&self) -> &T

Get a reference to the nested column as a specific type

Example
let col: ColumnArray = /* ... */;
let nested: &ColumnUInt32 = col.nested();
pub fn nested_mut<T: Column + 'static>(&mut self) -> &mut T

Get mutable reference to the nested column as a specific type

Example
let mut col: ColumnArray = /* ... */;
let nested_mut: &mut ColumnUInt32 = col.nested_mut();
pub fn nested_ref(&self) -> ColumnRef

Get the nested column as a ColumnRef (Arc<dyn Column>)

pub fn offsets(&self) -> &[u64]

Get the offsets

pub fn append_array(&mut self, array_data: ColumnRef)

Append an entire array column as a single array element This takes all the data from the provided column and adds it as one array

pub fn at(&self, index: usize) -> ColumnRef

Get the array at the given index as a sliced column

pub fn len(&self) -> usize

Get the number of arrays (alias for size())

pub fn is_empty(&self) -> bool

Check if the array column is empty