pub struct ColumnLowCardinality { /* private fields */ }Expand description
Column for LowCardinality type (dictionary encoding)
Stores unique values in a dictionary and uses indices to reference them, providing compression for columns with many repeated values.
Reference Implementation: See
clickhouse-cpp/clickhouse/columns/lowcardinality.cpp
Implementations
Sourceimpl ColumnLowCardinality
impl ColumnLowCardinality
Sourcepub fn dictionary<T: Column + 'static>(&self) -> &T
pub fn dictionary<T: Column + 'static>(&self) -> &T
Sourcepub fn dictionary_mut<T: Column + 'static>(&mut self) -> &mut T
pub fn dictionary_mut<T: Column + 'static>(&mut self) -> &mut T
Sourcepub fn dictionary_ref(&self) -> ColumnRef
pub fn dictionary_ref(&self) -> ColumnRef
Get the dictionary column as a ColumnRef (Arc<dyn Column>)
Sourcepub fn dictionary_size(&self) -> usize
pub fn dictionary_size(&self) -> usize
Get the number of unique values in the dictionary
Sourcepub fn append_unsafe(&mut self, value: &ColumnValue) -> Result<()>
pub fn append_unsafe(&mut self, value: &ColumnValue) -> Result<()>
Append a value with hash-based deduplication (like C++ AppendUnsafe) This is the core method for adding values to LowCardinality columns
Sourcepub fn append_values<I>(&mut self, values: I) -> Result<()>where
I: IntoIterator<Item = ColumnValue>,
pub fn append_values<I>(&mut self, values: I) -> Result<()>where
I: IntoIterator<Item = ColumnValue>,
Bulk append values from an iterator with deduplication