pub struct ColumnTuple { /* private fields */ }Expand description
Column for tuple types (fixed number of heterogeneous columns).
Implementations
Sourceimpl ColumnTuple
impl ColumnTuple
Sourcepub fn new(type_: Type, columns: Vec<ColumnRef>) -> Self
pub fn new(type_: Type, columns: Vec<ColumnRef>) -> Self
Create a new tuple column with the given type and element columns.
Sourcepub fn column_count(&self) -> usize
pub fn column_count(&self) -> usize
Get the number of columns in the tuple
Sourcepub fn column_at(&self, index: usize) -> ColumnRef
pub fn column_at(&self, index: usize) -> ColumnRef
Get a reference to a specific column in the tuple
Sourcepub fn column_at_mut(&mut self, index: usize) -> &mut dyn Column
pub fn column_at_mut(&mut self, index: usize) -> &mut dyn Column
Get mutable reference to a specific column (for appending)