pub struct BlockReader { /* private fields */ }Expand description
Reader for blocks from network
Implementations
Sourceimpl BlockReader
impl BlockReader
Sourcepub fn with_compression(self, method: CompressionMethod) -> Self
pub fn with_compression(self, method: CompressionMethod) -> Self
Enable compression
Sourcepub async fn read_block(&self, conn: &mut Connection) -> Result<Block>
pub async fn read_block(&self, conn: &mut Connection) -> Result<Block>
Read a block from the connection.
For compressed connections, ClickHouse may split a single logical block across multiple compressed frames (each frame ≤ max_compress_block_size, typically 1 MB). This method reads frames until the accumulated decompressed data forms a complete block.
Note: Caller is responsible for skipping temp table name if needed (matches C++ ReadBlock / CompressedInput).