BlockWriter

Struct BlockWriter 

pub struct BlockWriter { /* private fields */ }
Writer for blocks to network

Implementations

Source

impl BlockWriter

pub fn new(server_revision: u64) -> Self

Create a new block writer

pub fn with_compression(self, method: CompressionMethod) -> Self

Enable compression

pub async fn write_block( &self, conn: &mut Connection, block: &Block, ) -> Result<()>

Write a block to the connection

pub async fn write_block_with_temp_table( &self, conn: &mut Connection, block: &Block, write_temp_table_name: bool, ) -> Result<()>

Write a block to the connection (with optional temp table name)

If write_temp_table_name is true, writes an empty temp table name before the block. For external tables, set to false since the table name was already written.