pub struct QuerySettingsField {
pub value: String,
pub flags: u64,
}Expand description
Query settings field with flags
Settings can have flags that indicate their importance and scope:
- IMPORTANT: Setting is critical for query execution
- CUSTOM: User-defined setting
- OBSOLETE: Deprecated setting (for backward compatibility)
Fields
value: StringSetting value
flags: u64Setting flags (bitwise OR of IMPORTANT, CUSTOM, OBSOLETE)
Implementations
Sourceimpl QuerySettingsField
impl QuerySettingsField
Sourcepub fn new(value: impl Into<String>) -> Self
pub fn new(value: impl Into<String>) -> Self
Create a new settings field with value and no flags
Sourcepub fn with_flags(value: impl Into<String>, flags: u64) -> Self
pub fn with_flags(value: impl Into<String>, flags: u64) -> Self
Create a new settings field with value and flags
Sourcepub fn is_important(&self) -> bool
pub fn is_important(&self) -> bool
Check if setting has IMPORTANT flag
Sourcepub fn is_obsolete(&self) -> bool
pub fn is_obsolete(&self) -> bool
Check if setting has OBSOLETE flag