pub struct BlockWriter { /* private fields */ }Expand description
Writer for blocks to network
Implementations
Sourceimpl BlockWriter
impl BlockWriter
Sourcepub fn with_compression(self, method: CompressionMethod) -> Self
pub fn with_compression(self, method: CompressionMethod) -> Self
Enable compression
Sourcepub async fn write_block(
&self,
conn: &mut Connection,
block: &Block,
) -> Result<()>
pub async fn write_block( &self, conn: &mut Connection, block: &Block, ) -> Result<()>
Write a block to the connection
Sourcepub async fn write_block_with_temp_table(
&self,
conn: &mut Connection,
block: &Block,
write_temp_table_name: bool,
) -> Result<()>
pub async fn write_block_with_temp_table( &self, conn: &mut Connection, block: &Block, write_temp_table_name: bool, ) -> Result<()>
Write a block to the connection (with optional temp table name)
If write_temp_table_name is true, writes an empty temp table name
before the block. For external tables, set to false since the table
name was already written.