ClientCode

Enum ClientCode 

#[repr(u64)]
pub enum ClientCode { Hello = 0, Query = 1, Data = 2, Cancel = 3, Ping = 4, }
Types of packets sent by client

Variants



Hello = 0

Client handshake containing name, version, and default database.



Query = 1

Query packet with query id, settings, stage, compression, and query text.



Data = 2

Data block (e.g. INSERT data), may be compressed.



Cancel = 3

Cancel the currently running query.



Ping = 4

Ping the server to check the connection is alive.